==> hb-common-0.1.2.tgz: package/src/config/microAppsConfig.js <==
import appConfig from './appConfig'
let microAppsConfig = {
  whiteList: [
    appConfig.myHttp+':1103'
  ],
  microApps: [{
    name: 'hb-production-management', // 项目名称
    entry: getEntry('hb-production-management','1103'),// 项目地址
    activeRule: '/#/layout/production-management',
  },{
    name: 'tss', // 项目名称
    entry: getEntry('tss','1106'), // 项目地址
    activeRule: '/#/layout/tss', // 路由激活规则
  },{
    name: 'sys', // 项目名称
    entry: getEntry('sys','1111'), // 项目地址
    activeRule: '/#/layout/sys', // 路由激活规则
  },{
    name: 'contract', // 项目名称
    entry: getEntry('contract','1105'), // 项目地址
    activeRule: '/#/layout/contract', // 路由激活规则
  },{
    name: 'scm', // 项目名称
    entry: getEntry('scm','1104'), // 项目地址
    activeRule: '/#/layout/scm', // 路由激活规则
  },{
    name: 'wfs', // 项目名称
    entry: getEntry('wfs','1108'), // 项目地址
    activeRule: '/#/layout/wfs', // 路由激活规则
  },{
    name: 'plm', // 项目名称
    entry: getEntry('plm','1112'), // 项目地址
    activeRule: '/#/layout/plm', // 路由激活规则
  },{
    name: 'fms', // 项目名称
    entry: getEntry('plm','1109'), // 项目地址
    activeRule: '/#/layout/fms', // 路由激活规则
  },{
    name: 'hb-crm', // 项目名称
    entry: getEntry('hb-crm','1107'), // 项目地址
    activeRule: '/#/layout/crm', // 路由激活规则
  },{
    name: 'file', // 项目名称
    entry: getEntry('file','1113'), // 项目地址
    activeRule: '/#/layout/file', // 路由激活规则
  },{
    name: 'hrs', // 项目名称
    entry: getEntry('hrs','1114'), // 项目地址
    activeRule: '/#/layout/hrs', // 路由激活规则
  },{
    name: 'tss-project', // 项目名称
    entry: process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:2201`:'/child/tss-project/', // 项目地址
    activeRule: '/#/tss-project', // 路由激活规则
  },{
    name: 'work-flow', // 项目名称
    entry: process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:2202`:'/child/work-flow/', // 项目地址
    activeRule: '/#/work-flow', // 路由激活规则
  }]
}

function getEntry(name,port){
  return process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:${port}`: `/child/${name}/`
}

export default microAppsConfig

==> hb-common-0.1.4.tgz: package/src/config/microAppsConfig.js <==
import appConfig from './appConfig'
let microAppsConfig = {
  whiteList: [
    appConfig.myHttp+':1103'
  ],
  microApps: [{
    name: 'production-management', // 项目名称
    entry: getEntry('production-management','1103'),// 项目地址
    activeRule: '/#/layout/production-management',
  },{
    name: 'tss', // 项目名称
    entry: getEntry('tss','1106'), // 项目地址
    activeRule: '/#/layout/tss', // 路由激活规则
  },{
    name: 'sys', // 项目名称
    entry: getEntry('sys','1111'), // 项目地址
    activeRule: '/#/layout/sys', // 路由激活规则
  },{
    name: 'contract', // 项目名称
    entry: getEntry('contract','1105'), // 项目地址
    activeRule: '/#/layout/contract', // 路由激活规则
  },{
    name: 'scm', // 项目名称
    entry: getEntry('scm','1104'), // 项目地址
    activeRule: '/#/layout/scm', // 路由激活规则
  },{
    name: 'wfs', // 项目名称
    entry: getEntry('wfs','1108'), // 项目地址
    activeRule: '/#/layout/wfs', // 路由激活规则
  },{
    name: 'plm', // 项目名称
    entry: getEntry('plm','1112'), // 项目地址
    activeRule: '/#/layout/plm', // 路由激活规则
  },{
    name: 'fms', // 项目名称
    entry: getEntry('plm','1109'), // 项目地址
    activeRule: '/#/layout/fms', // 路由激活规则
  },{
    name: 'crm', // 项目名称
    entry: getEntry('crm','1107'), // 项目地址
    activeRule: '/#/layout/crm', // 路由激活规则
  },{
    name: 'file', // 项目名称
    entry: getEntry('file','1113'), // 项目地址
    activeRule: '/#/layout/file', // 路由激活规则
  },{
    name: 'hrs', // 项目名称
    entry: getEntry('hrs','1114'), // 项目地址
    activeRule: '/#/layout/hrs', // 路由激活规则
  },{
    name: 'tss-project', // 项目名称
    entry: process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:2201`:'/child/tss-project/', // 项目地址
    activeRule: '/#/tss-project', // 路由激活规则
  },{
    name: 'work-flow', // 项目名称
    entry: process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:2202`:'/child/work-flow/', // 项目地址
    activeRule: '/#/work-flow', // 路由激活规则
  }]
}

function getEntry(name,port){
  return process.env.NODE_ENV == 'development'?`${appConfig.myHttp}:${port}`: `/child/${name}/`
}

export default microAppsConfig
